<?php
/**
 * Plugin Name: Bayarcash for Paymattic
 * Plugin URI: https://bayarcash.com
 * Description: Bayarcash is a local Malaysia payment gateway that support FPX, Direct Debit, DuitNow QR, DuitNow Online Banking/Wallets, BNPL (SPayLater & Boost PayFlex) as well cross-border payment (Indonesia, Singapore & Thailand).
 * Version: 1.0.0
 * Author: Web Impian
 * Author URI: https://webimpian.com
 * License: GNU General Public License v3.0
 * License URI: https://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain: bayarcash-for-paymattic
 * Requires PHP: 7.4
 * Requires at least: 5.0
 * Tested up to: 6.7
 */

use BayarcashPaymattic\Plugin;

if (!defined('ABSPATH')) {
	die;
}

const PAYMATTIC_BAYARCASH_MODULE_VERSION = 'v1.0.0';

// Define plugin constants
const PAYMATTIC_BAYARCASH_FILE           = __FILE__;
const PAYMATTIC_BAYARCASH_SLUG           = 'paymattic_bayarcash';
define('PAYMATTIC_BAYARCASH_BASENAME', plugin_basename(__FILE__));
define('PAYMATTIC_BAYARCASH_DIR_PATH', plugin_dir_path(__FILE__));
define('PAYMATTIC_BAYARCASH_URL', plugin_dir_url(__FILE__));

// Load Composer's autoloader
$composer_autoloader = PAYMATTIC_BAYARCASH_DIR_PATH . 'vendor/autoload.php';
if (!file_exists($composer_autoloader)) {
	add_action('admin_notices', function() {
		?>
        <div class="notice notice-error">
            <p><?php _e('Bayarcash for Paymattic: Required dependencies are missing. Please run "composer install" in the plugin directory.', 'bayarcash-for-paymattic'); ?></p>
        </div>
		<?php
	});
	return;
}
require_once $composer_autoloader;

// Verify Bayarcash SDK is loaded
if (!class_exists('\Webimpian\BayarcashSdk\Bayarcash')) {
	add_action('admin_notices', function() {
		?>
        <div class="notice notice-error">
            <p><?php _e('Bayarcash for Paymattic: Bayarcash SDK could not be loaded. Please check your installation.', 'bayarcash-for-paymattic'); ?></p>
        </div>
		<?php
	});
	return;
}

// Initialize the plugin with priority 11
add_action('plugins_loaded', function() {
	// Check for required dependencies
	if (!class_exists('WPPayFormPro') || !class_exists('WPPayFormPro\GateWays\BasePaymentMethod')) {
		add_action('admin_notices', function() {
			?>
            <div class="notice notice-error">
                <p><?php _e('Bayarcash for Paymattic requires Paymattic to be installed and activated.', 'bayarcash-for-paymattic'); ?></p>
            </div>
			<?php
		});
		return;
	}

	Plugin::get_instance();
}, 11);

// Load CSF framework
add_action('plugins_loaded', 'load_bayarcash_for_paymattic_csf');
function load_bayarcash_for_paymattic_csf() {
	include PAYMATTIC_BAYARCASH_DIR_PATH . 'includes/codestar-framework/classes/setup.class.php';
}