<?php

use WPPayForm\App\Models\Form;

$slug = PAYMATTIC_BAYARCASH_SLUG;

function pymtc_bayarcash_form_fields($form): array {
	$pymtc_form_currency = Form::getCurrencySettings($form->ID);

	return array(
		array(
			'id'    => 'form-customize-' . $form->ID,
			'type'  => 'switcher',
			'title' => __('Customization', 'bayarcash-for-paymattic'),
			'desc'  => sprintf(__('Form ID: <strong>#%s</strong>. Form Title: <strong>%s</strong>', 'bayarcash-for-paymattic'), $form->ID, $form->post_title),
			'help'  => sprintf(__('This to enable customization per form-basis for form: #%s', 'bayarcash-for-paymattic'), $form->ID),
		),
		array(
			'type'    => 'notice',
			'style'   => 'danger',
			'content' => sprintf(__('The default currency is set to non compatible currencies! %sClick here%s to update currency configuration.', 'bayarcash-for-paymattic'), '<a target=_blank href=' . admin_url('admin.php?page=wppayform.php#/edit-form/' . $form->ID . '/settings/currency_settings') . ' >', '</a>'),
			'class'   => $pymtc_form_currency['currency'] == 'MYR' ? 'hidden' : '',
		),
		array(
			'type'    => 'notice',
			'style'   => 'normal',
			'content' => __('Note: Please add Email and Name field on your form to get payment data correctly.', 'bayarcash-for-paymattic'),
			'dependency' => array(['form-customize-' . $form->ID, '==', 'true']),
		),
		array(
			'type'    => 'subheading',
			'content' => 'Credentials',
			'dependency' => array(['form-customize-' . $form->ID, '==', 'true']),
		),
		array(
			'id'    => 'enable-sandbox-' . $form->ID,
			'type'  => 'switcher',
			'title' => __('Enable Sandbox Mode', 'bayarcash-for-paymattic'),
			'desc'  => __('Toggle this to switch between sandbox and production environments.', 'bayarcash-for-paymattic'),
			'help'  => __('Use sandbox mode to test payments without processing real transactions.', 'bayarcash-for-paymattic'),
			'dependency' => array(['form-customize-' . $form->ID, '==', 'true']),
			'class' => 'bc-sandbox-switcher-' . $form->ID,
		),
		array(
			'id'         => 'sandbox-notice-' . $form->ID,
			'type'       => 'notice',
			'style'      => 'warning',
			'content'    => __('Sandbox mode is enabled. Make sure to use sandbox credentials for testing.', 'bayarcash-for-paymattic'),
			'dependency' => array(['enable-sandbox-' . $form->ID, '==', 'true'], ['form-customize-' . $form->ID, '==', 'true']),
		),
		array(
			'id'    => 'personal-access-token-' . $form->ID,
			'type'  => 'textarea',
			'title' => __('Personal Access Token', 'bayarcash-for-paymattic'),
			'desc'  => sprintf(__('Enter your Personal Access Token. Get it from %sBayarcash Console Profile%s', 'bayarcash-for-paymattic'), '<a href="https://console.bayar.cash/profile" target="_blank">', '</a>'),
			'help'  => __('Personal Access Token is used to authenticate your requests to the Bayarcash API.', 'bayarcash-for-paymattic'),
			'dependency' => array(['form-customize-' . $form->ID, '==', 'true']),
			'after' => '
		    <div class="bc-token-status-' . $form->ID . '" style="margin-top: 10px;">
		        <span class="status-message"></span>
		        <button type="button" class="button button-secondary verify-token" style="margin-left: 10px;">
		            ' . __('Verify Token', 'bayarcash-for-paymattic') . '
		        </button>
		    </div>
		'
		),
		array(
			'id'    => 'portal-key-' . $form->ID,
			'type'  => 'text',
			'title' => __('Portal Key', 'bayarcash-for-paymattic'),
			'desc'  => sprintf(__('Enter your Portal Key. Get it from %sBayarcash Console Profile%s', 'bayarcash-for-paymattic'), '<a href="https://console.bayar.cash/portals" target="_blank">', '</a>'),
			'help'  => __('Portal Key is required for accessing the Bayarcash portal features.', 'bayarcash-for-paymattic'),
			'dependency' => array(['form-customize-' . $form->ID, '==', 'true']),
		),
		array(
			'id'    => 'api-secret-key-' . $form->ID,
			'type'  => 'text',
			'title' => __('API Secret Key', 'bayarcash-for-paymattic'),
			'desc'  => sprintf(__('Enter your API Secret Key. Get it from %sBayarcash Console Profile%s', 'bayarcash-for-paymattic'), '<a href="https://console.bayar.cash/profile" target="_blank">', '</a>'),
			'help'  => __('API Secret Key is used to secure your API requests to Bayarcash.', 'bayarcash-for-paymattic'),
			'dependency' => array(['form-customize-' . $form->ID, '==', 'true']),
		),
	);
}

CSF_Setup::createSection($slug, array(
	'id'    => 'form-configuration',
	'title' => __('Form Configuration', 'bayarcash-for-paymattic'),
	'icon'  => 'fa fa-gear'
));

$all_forms_query = Form::getAllForms();

foreach ($all_forms_query as $form) {
	CSF_Setup::createSection($slug, array(
		'parent'      => 'form-configuration',
		'id'          => 'form-id-' . $form->ID,
		'title'       => sprintf(__('Form #%s - %s', 'bayarcash-for-paymattic'), $form->ID, substr($form->post_title, 0, 15)),
		'description' => sprintf(__('Configuration for Form #%s - %s', 'bayarcash-for-paymattic'), $form->ID, $form->post_title),
		'fields'      => pymtc_bayarcash_form_fields($form),
	));
}