<?php
if (!defined('PAYMATTIC_BAYARCASH_SLUG')) {
	define('PAYMATTIC_BAYARCASH_SLUG', 'paymattic_bayarcash');
}

$slug = PAYMATTIC_BAYARCASH_SLUG;

// Simplified payment channel definition
$channel_groups = [
	'malaysia' => [
		'title' => __('Bayarcash Gateway Fee', 'bayarcash-for-paymattic'),
		'channels' => [
			'fpx_banking' => __('FPX Online Banking', 'bayarcash-for-paymattic'),
			'credit_card' => __('Credit Card', 'bayarcash-for-paymattic'),
			'duitnow_banking' => __('DuitNow Online Banking', 'bayarcash-for-paymattic'),
			'duitnow_qr' => __('DuitNow QR', 'bayarcash-for-paymattic'),
		]
	]
];

if (!function_exists('paymattic_generate_channel_fee_fields')) {
	function paymattic_generate_channel_fee_fields($channels): array {
		$fields = [];

		foreach ($channels as $channel_key => $channel_label) {
			$base_dependency = ["{$channel_key}_fee_enable", '==', 'true'];

			$fields = array_merge($fields, [
				[
					'id' => "{$channel_key}_fee_enable",
					'type' => 'switcher',
					'title' => sprintf(__('Enable %s Fees', 'bayarcash-for-paymattic'), $channel_label),
					'default' => false
				],
				[
					'id' => "{$channel_key}_fee_type",
					'type' => 'select',
					'title' => sprintf(__('%s Fee Type', 'bayarcash-for-paymattic'), $channel_label),
					'options' => [
						'flat' => __('Flat Fee Only', 'bayarcash-for-paymattic'),
						'percentage' => __('Percentage Only', 'bayarcash-for-paymattic'),
						'both' => __('Both Flat + Percentage', 'bayarcash-for-paymattic')
					],
					'dependency' => $base_dependency,
					'default' => 'flat'
				],
				[
					'id' => "{$channel_key}_flat_fee",
					'type' => 'number',
					'title' => sprintf(__('%s Flat Fee Amount (RM)', 'bayarcash-for-paymattic'), $channel_label),
					'subtitle' => __('Fixed amount to charge', 'bayarcash-for-paymattic'),
					'default' => '0',
					'step' => '0.01',
					'dependency' => [
						$base_dependency,
						["{$channel_key}_fee_type", 'any', 'flat,both']
					]
				],
				[
					'id' => "{$channel_key}_percentage_fee",
					'type' => 'number',
					'title' => sprintf(__('%s Percentage Fee', 'bayarcash-for-paymattic'), $channel_label) . ' (%)',
					'subtitle' => __('Percentage of transaction amount', 'bayarcash-for-paymattic'),
					'default' => '0',
					'step' => '0.01',
					'dependency' => [
						$base_dependency,
						["{$channel_key}_fee_type", 'any', 'percentage,both']
					]
				],
				[
					'id' => "{$channel_key}_fee_description",
					'type' => 'text',
					'title' => sprintf(__('%s Fee Description', 'bayarcash-for-paymattic'), $channel_label),
					'subtitle' => __('Description shown to customers', 'bayarcash-for-paymattic'),
					'default' => sprintf(__('%s Processing Fee', 'bayarcash-for-paymattic'), $channel_label),
					'dependency' => $base_dependency
				],
				[
					'type' => 'submessage',
					'style' => 'info',
					'content' => '<hr style="border-top: 2px solid #eee; margin: 15px 0;">'
				]
			]);
		}

		return $fields;
	}
}

// Create sections for each channel group
foreach ($channel_groups as $group_key => $group_data) {
	CSF_Setup::createSection($slug, [
		'id' => "channel-fees-{$group_key}",
		'title' => $group_data['title'],
		'icon' => 'fa fa-percentage',
		'description' => __('Configure fees for payment channels.', 'bayarcash-for-paymattic'),
		'fields' => paymattic_generate_channel_fee_fields($group_data['channels'])
	]);
}