<?php

namespace BayarcashPaymattic;

use WPPayFormPro\GateWays\BasePaymentMethod;
use WPPayForm\Framework\Support\Arr;

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

class Settings extends BasePaymentMethod
{
	private static array $_instances = [];

	private static $available_channels = [
		'fpx_banking' => [
			'title' => 'FPX Online Banking',
			'text_domain' => 'fpx-banking-paymattic',
			'logo' => 'fpx-banking.png'
		],
		'credit_card' => [
			'title' => 'Credit Card',
			'text_domain' => 'credit-card-paymattic',
			'logo' => 'credit-card.png'
		],
		'duitnow_banking' => [
			'title' => 'DuitNow Online Banking',
			'text_domain' => 'duitnow-banking-paymattic',
			'logo' => 'duitnow-banking.png'
		],
		'duitnow_qr' => [
			'title' => 'DuitNow QR',
			'text_domain' => 'duitnow-qr-paymattic',
			'logo' => 'duitnow-qr.png'
		],
		'spaylater' => [
			'title' => 'SPayLater',
			'text_domain' => 'spaylater-paymattic',
			'logo' => 'spaylater.png'
		],
		'boost_payflex' => [
			'title' => 'Boost PayFlex',
			'text_domain' => 'boost-payflex-paymattic',
			'logo' => 'boost-payflex.png'
		],
		'indo_banking' => [
			'title' => 'Indonesia Online Banking',
			'text_domain' => 'indo-banking-paymattic',
			'logo' => 'indo-banking.png'
		],
		'indo_ewallet' => [
			'title' => 'Indonesia e-Wallet',
			'text_domain' => 'indo-ewallet-paymattic',
			'logo' => 'indo-banking.png'
		],
		'nets_sg' => [
			'title' => 'NETS Singapore',
			'text_domain' => 'nets-sg-paymattic',
			'logo' => 'nets-sg.png'
		]
	];

	private $channel;
	private array $channel_config;

	public static function get_instance($channel)
	{
		if (!isset(self::$_instances[$channel])) {
			self::$_instances[$channel] = new self($channel);
		}
		return self::$_instances[$channel];
	}

	public static function init_all_channels()
	{
		foreach (array_keys(self::$available_channels) as $channel) {
			self::get_instance($channel);
		}
	}

	private function __construct($channel)
	{
		if (!isset(self::$available_channels[$channel])) {
			throw new \InvalidArgumentException("Invalid payment channel: $channel");
		}

		$this->channel = $channel;
		$this->channel_config = self::$available_channels[$channel];

		parent::__construct(
			$channel,
			$this->channel_config['title'],
			[],
			PAYMATTIC_BAYARCASH_URL . 'assets/images/' . $this->channel_config['logo']
		);
	}

	public function globalFields(): array
	{
		return array(
			'is_active' => array(
				'value' => 'yes',
				'label' => __('Enable/Disable', 'bayarcash-for-paymattic'),
			)
		);
	}

	public static function settingsKeys(): array
	{
		return array(
			'is_active' => 'yes'
		);
	}

	public static function getSettings(): array
	{
		$settings = get_option('wppayform_payment_settings_bayarcash', array());
		return wp_parse_args($settings, static::settingsKeys());
	}

	public function getPaymentSettings(): array
	{
		$settings = $this->mapper(
			static::getSettings()
		);

		return array(
			'settings' => $settings,
		);
	}
}